##Title: General comparisons between all fire behaviour prediction methods as well as observed fire behaviour. Includes ANOVA, RMSE, and figures.

##Authors: Charles D. Davis, G. Matt Davies

##Date Last Modified: 23 February 2022

#Library for rstudio functions
install.packages ("rstudioapi")
library (rstudioapi)

#Getting the path of your current open file
current_path <- rstudioapi::getActiveDocumentContext()$path 
setwd(dirname(current_path))
print(getwd())

#Install and Load in requisite libraries
install.packages ("Rothermel")
install.packages ("Rmisc")
install.packages ("Metrics")
install.packages ("pwr2")
install.packages ("tidyverse")

library (Rothermel)
library (Rmisc)
library (Metrics)
library (pwr2)
library (tidyverse)
library (readxl)

#Read in appropriate data
data <- read_excel("1A.ObservationsVersusModeling.xlsx", sheet = "FuelModels")
data <- as.data.frame(data)

#Create easy set of variables for resulting rate of spread calculations - Vacchiano and Ascoli (2015)
ROS1 <- ros(data[1, 9], data[1, 10:14], data[1, 15:19], data[1, 20], data[1, 21], data[1, 22:26], data[1, 27:31], data[1, 32], data[1, 33])
ROS2 <- ros(data[2, 9], data[2, 10:14], data[2, 15:19], data[2, 20], data[2, 21], data[2, 22:26], data[2, 27:31], data[2, 32], data[2, 33])
ROS3 <- ros(data[3, 9], data[3, 10:14], data[3, 15:19], data[3, 20], data[3, 21], data[3, 22:26], data[3, 27:31], data[3, 32], data[3, 33])
ROS4 <- ros(data[4, 9], data[4, 10:14], data[4, 15:19], data[4, 20], data[4, 21], data[4, 22:26], data[4, 27:31], data[4, 32], data[4, 33])
ROS5 <- ros(data[5, 9], data[5, 10:14], data[5, 15:19], data[5, 20], data[5, 21], data[5, 22:26], data[5, 27:31], data[5, 32], data[5, 33])
ROS6 <- ros(data[6, 9], data[6, 10:14], data[6, 15:19], data[6, 20], data[6, 21], data[6, 22:26], data[6, 27:31], data[6, 32], data[6, 33])
ROS7 <- ros(data[7, 9], data[7, 10:14], data[7, 15:19], data[7, 20], data[7, 21], data[7, 22:26], data[7, 27:31], data[7, 32], data[7, 33])
ROS8 <- ros(data[8, 9], data[8, 10:14], data[8, 15:19], data[8, 20], data[8, 21], data[8, 22:26], data[8, 27:31], data[8, 32], data[8, 33])
ROS9 <- ros(data[9, 9], data[9, 10:14], data[9, 15:19], data[9, 20], data[9, 21], data[9, 22:26], data[9, 27:31], data[9, 32], data[9, 33])
ROS10 <- ros(data[10, 9], data[10, 10:14], data[10, 15:19], data[10, 20], data[10, 21], data[10, 22:26], data[10, 27:31], data[10, 32], data[10, 33])
ROS11 <- ros(data[11, 9], data[11, 10:14], data[11, 15:19], data[11, 20], data[11, 21], data[11, 22:26], data[11, 27:31], data[11, 32], data[11, 33])
ROS12 <- ros(data[12, 9], data[12, 10:14], data[12, 15:19], data[12, 20], data[12, 21], data[12, 22:26], data[12, 27:31], data[12, 32], data[12, 33])
ROS13 <- ros(data[13, 9], data[13, 10:14], data[13, 15:19], data[13, 20], data[13, 21], data[13, 22:26], data[13, 27:31], data[13, 32], data[13, 33])
ROS14 <- ros(data[14, 9], data[14, 10:14], data[14, 15:19], data[14, 20], data[14, 21], data[14, 22:26], data[14, 27:31], data[14, 32], data[14, 33])
ROS15 <- ros(data[15, 9], data[15, 10:14], data[15, 15:19], data[15, 20], data[15, 21], data[15, 22:26], data[15, 27:31], data[15, 32], data[15, 33])
ROS16 <- ros(data[16, 9], data[16, 10:14], data[16, 15:19], data[16, 20], data[16, 21], data[16, 22:26], data[16, 27:31], data[16, 32], data[16, 33]) 
ROS17 <- ros(data[17, 9], data[17, 10:14], data[17, 15:19], data[17, 20], data[17, 21], data[17, 22:26], data[17, 27:31], data[17, 32], data[17, 33])
ROS18 <- ros(data[18, 9], data[18, 10:14], data[18, 15:19], data[18, 20], data[18, 21], data[18, 22:26], data[18, 27:31], data[18, 32], data[18, 33])
ROS19 <- ros(data[19, 9], data[19, 10:14], data[19, 15:19], data[19, 20], data[19, 21], data[19, 22:26], data[19, 27:31], data[19, 32], data[19, 33])
ROS20 <- ros(data[20, 9], data[20, 10:14], data[20, 15:19], data[20, 20], data[20, 21], data[20, 22:26], data[20, 27:31], data[20, 32], data[20, 33])
ROS21 <- ros(data[21, 9], data[21, 10:14], data[21, 15:19], data[21, 20], data[21, 21], data[21, 22:26], data[21, 27:31], data[21, 32], data[21, 33])
ROS22 <- ros(data[22, 9], data[22, 10:14], data[22, 15:19], data[22, 20], data[22, 21], data[22, 22:26], data[22, 27:31], data[22, 32], data[22, 33])
ROS23 <- ros(data[23, 9], data[23, 10:14], data[23, 15:19], data[23, 20], data[23, 21], data[23, 22:26], data[23, 27:31], data[23, 32], data[23, 33])
ROS24 <- ros(data[24, 9], data[24, 10:14], data[24, 15:19], data[24, 20], data[24, 21], data[24, 22:26], data[24, 27:31], data[24, 32], data[24, 33])
ROS25 <- ros(data[25, 9], data[25, 10:14], data[25, 15:19], data[25, 20], data[25, 21], data[25, 22:26], data[25, 27:31], data[25, 32], data[25, 33])
ROS26 <- ros(data[26, 9], data[26, 10:14], data[26, 15:19], data[26, 20], data[26, 21], data[26, 22:26], data[26, 27:31], data[26, 32], data[26, 33])
ROS27 <- ros(data[27, 9], data[27, 10:14], data[27, 15:19], data[27, 20], data[27, 21], data[27, 22:26], data[27, 27:31], data[27, 32], data[27, 33])

#Matrix to store everything, sorted, after modeling
roscomp <- matrix(ncol = 9, nrow = 27)
colnames(roscomp) <- c("Obs", "Roth", "Davies1", "Davies2", "Anderson", "BEH", "FAR", "Corrected", "LineLength")
roscomp[, 9] <- data[, 36]

#store Rothermel rates of spread into matrix
roscomp[1:27, 1] <- data[1:27, 3]
roscomp[1:27, 6] <- data[1:27, 34]
roscomp[1:27, 7] <- data[1:27, 35]
roscomp[1, 2] <- as.numeric(ROS1[15])
roscomp[2, 2] <- as.numeric(ROS2[15])
roscomp[3, 2] <- as.numeric(ROS3[15])
roscomp[4, 2] <- as.numeric(ROS4[15])
roscomp[5, 2] <- as.numeric(ROS5[15])
roscomp[6, 2] <- as.numeric(ROS6[15])
roscomp[7, 2] <- as.numeric(ROS7[15])
roscomp[8, 2] <- as.numeric(ROS8[15])
roscomp[9, 2] <- as.numeric(ROS9[15])
roscomp[10, 2] <- as.numeric(ROS10[15])
roscomp[11, 2] <- as.numeric(ROS11[15])
roscomp[12, 2] <- as.numeric(ROS12[15])
roscomp[13, 2] <- as.numeric(ROS13[15])
roscomp[14, 2] <- as.numeric(ROS14[15])
roscomp[15, 2] <- as.numeric(ROS15[15])
roscomp[16, 2] <- as.numeric(ROS16[15])
roscomp[17, 2] <- as.numeric(ROS17[15])
roscomp[18, 2] <- as.numeric(ROS18[15])
roscomp[19, 2] <- as.numeric(ROS19[15])
roscomp[20, 2] <- as.numeric(ROS20[15])
roscomp[21, 2] <- as.numeric(ROS21[15])
roscomp[22, 2] <- as.numeric(ROS22[15])
roscomp[23, 2] <- as.numeric(ROS23[15])
roscomp[24, 2] <- as.numeric(ROS24[15])
roscomp[25, 2] <- as.numeric(ROS25[15])
roscomp[26, 2] <- as.numeric(ROS26[15])
roscomp[27, 2] <- as.numeric(ROS27[15])

#calculate and store Davies 1 rates of spread into matrix - Davies et al. (2009)
roscomp[1:27, 3] <- abs(0.791 + 7.917*((data[1:27, 20]/100)^2)*(data[1:27, 32]/3.6))

#calculate and store Davies 2 rates of spread into matrix - Davies et al. (2009)
roscomp[1:27, 4] <- abs(8.304 + 7.286*((data[1:27, 20]/100)^2)*(data[1:27, 32]/3.6) - 0.097*data[1:27, 31])

#calculate and store Anderson Equation 2 rates of spread into matrix - Anderson et al. (2015)
roscomp[1:27, 5] <- abs(6.421*((data[1:27, 32])^0.994)*((data[1:27, 20]/100)^0.372)*exp(-0.0761*data[1:27, 27])*exp(-0.00313*data[1:27, 31]))

##Correct observed values to compare with Anderson's longer ignition line lengths
roscomp[1:27, 8] <- data[1:27, 3]*(1+(9*exp(-0.00316*(data[1:27, 36]^2))))

#separate out results into variables
##For the rest of this script, OBS is observed fire spread values from Legg et al. (2007), ROTH is the R Rothermel implementation, 
##Pred1 is Davies 1, Pred2 is Davies 2, Pred3 or AND is Anderson, BEH is Behave, FAR is FARSITE, and Corr is the correction from Anderson et al. (2015)
##Behave - Andrews (2013), FARSITE - Finney (2004)
OBS <- roscomp[, 1]
ROTH <- roscomp[, 2]
Pred1 <- roscomp[, 3]
Pred2 <- roscomp[, 4]
Pred3 <- roscomp[, 5]
BEH <- roscomp[, 6]
FAR <- roscomp[, 7]
corr <- roscomp[, 8]

#linear models for confidence predictions and comparison
lm.ROTH <- lm(ROTH~OBS)
summary(lm.ROTH)
lm.Pred1 <- lm(Pred1~OBS)
summary(lm.Pred1)
lm.Pred2 <- lm(Pred2~OBS)
summary(lm.Pred2)
lm.Pred3 <- lm(Pred3~OBS)
summary(lm.Pred3)
lm.BEH <- lm(BEH~OBS)
summary(lm.BEH)
lm.FAR <- lm(FAR~OBS)
summary(lm.FAR)
lm.ANDcorr <- lm(Pred3~corr)
summary(lm.ANDcorr)
lpa <- lm(1~1)

#confidence intervals for eaach type of fire behaviour prediction model
R.ci <- CI(ROTH, ci = 0.95)
Emp1.ci <- CI(Pred1, ci = 0.95)
Emp2.ci <- CI(Pred2, ci = 0.95)
Emp3.ci <- CI(Pred3, ci = 0.95)
BEH.ci <- CI(BEH, ci = 0.95)
FAR.ci <- CI(FAR, ci = 0.95)
newx = seq(min(OBS), max(OBS), by = 1)
preds.ROTH <- predict(lm.ROTH, data.frame(OBS = newx), interval = "confidence") 
preds.Pred1 <- predict(lm.Pred1, data.frame(OBS = newx), interval = "confidence") 
preds.Pred2 <- predict(lm.Pred2, data.frame(OBS = newx), interval = "confidence") 
preds.Pred3 <- predict(lm.Pred3, data.frame(OBS = newx), interval = "confidence")
preds.BEH <- predict(lm.BEH, data.frame(OBS = newx), interval = "confidence") 
preds.FAR <- predict(lm.FAR, data.frame(OBS = newx), interval = "confidence")

newx.corr = seq(min(corr), max(corr), by = 1)
preds.ANDcorr <- predict(lm.ANDcorr, data.frame(corr = newx.corr), interval = "confidence")

#variables for transcribing R^2 values onto plots
LM.R2.D1 <- expression(R^2~"= 0.58")
LM.R2.D2 <- expression(R^2~"= 0.69")
LM.R2.An <- expression(R^2~"= 0.46")
LM.R2.Roth <- expression(R^2~"= 0.45")
LM.R2.BEH <- expression(R^2~"= 0.39")
LM.R2.FAR <- expression(R^2~"= 0.39")
LM.R2.AnCorr <- expression(R^2~"= 0.31")

#checking confidence predictions
mean(preds.ROTH[, 3])
mean(preds.ROTH[, 2])

mean(preds.Pred1[, 3])
mean(preds.Pred1[, 2])

mean(preds.Pred2[, 3])
mean(preds.Pred2[, 2])

mean(preds.Pred3[, 3])
mean(preds.Pred3[, 2])

mean(preds.BEH[, 3])
mean(preds.BEH[, 2])

mean(preds.FAR[, 3])
mean(preds.FAR[, 2])

mean(preds.ANDcorr[, 3])
mean(preds.ANDcorr[, 2])

#facet-plotting rate of spread modeling for all fire behaviour prediction models
par(mfrow = c(3, 2), mai = c(0.4, 0.4, 0.1, 0.1), oma = c(6, 2, 1, 1))

plot(roscomp[, 3]~roscomp[, 1], ylim = c(0, 30), yaxt = "n", xlab = "", ylab = "", cex = 1.5, pch = 21, cex.lab = 1.5, cex.axis = 1.5, col = "white", bg = "steelblue4")
axis(2, at = c(0, 5, 10, 15, 20, 25, 30), labels = c(0, "", 10, "", 20, "", 30), cex.axis = 1.5)
abline(lm(roscomp[, 3]~roscomp[, 1]), col = "steelblue4", lwd = 2)
matlines(newx, preds.Pred1[, 2:3], col = "steelblue4", lty = 2, lwd = 2)
text(1.5, 27.5, labels = LM.R2.D1, cex = 1.5)
abline(0, 1, lwd = 2)

plot(roscomp[, 4]~roscomp[, 1], ylim = c(0, 30), yaxt = "n", xlab = "", ylab = "", cex = 1.5, pch = 21, cex.lab = 1.5, cex.axis = 1.5, col = "white", bg = "skyblue2")
axis(2, at = c(0, 5, 10, 15, 20, 25, 30), labels = c(0, "", 10, "", 20, "", 30), cex.axis = 1.5)
abline(lm(roscomp[, 4]~roscomp[, 1]), col = "skyblue2", lwd = 2)
matlines(newx, preds.Pred2[, 2:3], col = "skyblue2", lty = 2, lwd = 2)
text(1.5, 27.5, labels = LM.R2.D2, cex = 1.5)
abline(0, 1, lwd = 2)

plot(roscomp[, 5]~roscomp[, 1], ylim = c(0, 30), yaxt = "n", xlab = "", ylab = "", cex = 1.5, pch = 21, cex.lab = 1.5, cex.axis = 1.5, col = "white", bg = "springgreen4")
axis(2, at = c(0, 5, 10, 15, 20, 25, 30), labels = c(0, "", 10, "", 20, "", 30), cex.axis = 1.5)
abline(lm(roscomp[, 5]~roscomp[, 1]), col = "springgreen4", lwd = 2)
matlines(newx, preds.Pred3[, 2:3], col = "springgreen4", lty = 2, lwd = 2)
text(1.5, 27.5, labels = LM.R2.An, cex = 1.5)
abline(0, 1, lwd = 2)

plot(roscomp[, 2]~roscomp[, 1], ylim = c(0, 30), yaxt = "n", xlab = "", ylab = "", cex = 1.5, pch = 21, cex.lab = 1.5, cex.axis = 1.5, col = "white", bg = "goldenrod")
axis(2, at = c(0, 5, 10, 15, 20, 25, 30), labels = c(0, "", 10, "", 20, "", 30), cex.axis = 1.5)
abline(lm(roscomp[, 2]~roscomp[, 1]), col = "goldenrod", lwd = 2)
matlines(newx, preds.ROTH[, 2:3], col = "goldenrod", lty = 2, lwd = 2)
text(1.5, 27.5, labels = LM.R2.Roth, cex = 1.5)
abline(0, 1, lwd = 2)

plot(roscomp[, 6]~roscomp[, 1], ylim = c(0, 30), yaxt = "n", xlab = "", ylab = "", cex = 1.5, pch = 21, cex.lab = 1.5, cex.axis = 1.5, col = "white", bg = "magenta3")
axis(2, at = c(0, 5, 10, 15, 20, 25, 30), labels = c(0, "", 10, "", 20, "", 30), cex.axis = 1.5)
abline(lm(roscomp[, 6]~roscomp[, 1]), col = "magenta3", lwd = 2)
matlines(newx, preds.BEH[, 2:3], col = "magenta3", lty = 2, lwd = 2)
text(1.5, 27.5, labels = LM.R2.BEH, cex = 1.5)
abline(0, 1, lwd = 2)

plot(roscomp[, 7]~roscomp[, 1], ylim = c(0, 30), yaxt = "n", xlab = "", ylab = "", cex = 1.5, pch = 21, cex.lab = 1.5, cex.axis = 1.5, col = "white", bg = "palevioletred2")
axis(2, at = c(0, 5, 10, 15, 20, 25, 30), labels = c(0, "", 10, "", 20, "", 30), cex.axis = 1.5)
abline(lm(roscomp[, 7]~roscomp[, 1]), col = "palevioletred2", lwd = 2)
matlines(newx, preds.FAR[, 2:3], col = "palevioletred2", lty = 2, lwd = 2)
text(1.5, 27.5, labels = LM.R2.FAR, cex = 1.5)
abline(0, 1, lwd = 2)

y <- expression("Predicted Rate of Spread ( m" ~ min^-1~")")
x <- expression("Observed Rate of Spread ( m" ~ min^-1~")")

par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0), mar = c(0, 0, 0, 0), new = TRUE)
plot(0, 0, type = "n", bty = "n", xaxt = "n", yaxt = "n")
text(-1.05, 0.12, labels = y, srt = 90, cex = 1.5)
text(0.03, -.9, labels = x, cex = 1.5)
legend(-0.6, -.9, legend = c("Davies 1", "Davies 2", "Anderson", "Roth"), col = c("steelblue4", "skyblue2", "springgreen4", "goldenrod"), bty = "n", lty = 1, y.intersp = 1.15, lwd = 2, cex = 1.2, seg.len = 1.2, horiz = TRUE)
legend(-0.47, -.96, legend = c("BehavePlus", "Farsite", "1:1"), col = c("magenta3", "palevioletred", "Black"), bty = "n", lty = 1, y.intersp = 1.15, lwd = 2, cex = 1.2, seg.len = 1.2, horiz = TRUE)

##Plot corrected fire behaviour vs Anderson as well as original observed vs Anderson to compare
y <- expression("Predicted Rate of Spread ( m" ~ min^-1~")")
x1 <- expression("Observed Rate of Spread ( m" ~ min^-1~")")
x2 <- expression("ESS Rate of Spread ( m" ~ min^-1~")")

par(mfrow = c(1, 2), mai = c(0.4, 0.6, 0.1, 0.1), oma = c(2.5, 2, 1, 1))

plot(roscomp[, 5]~roscomp[, 1], ylim = c(0, 30), xlim = c(0, 50), xlab = "", ylab = "", cex = 1.5, pch = c(21, 22)[as.factor(roscomp[, 9])], cex.lab = 1.5, cex.axis = 1.5, col = "white", bg = "springgreen4")
#text(-0.85, 0.95, labels = "A", cex = 1.5)
abline(lm(roscomp[, 5]~roscomp[, 1]), col = "springgreen4", lwd = 2)
matlines(newx, preds.Pred3[, 2:3], col = "springgreen4", lty = 2, lwd = 2)
legend("topright", legend = c("15", "20"), pch = c(21, 22), bty = "n", title = "ILL (m)  ", y.intersp = 0.75, cex = 1.2)
text(40, 2, labels = LM.R2.An, cex = 1.5)
abline(0, 1, lwd = 2)

plot(roscomp[, 5]~roscomp[, 8], ylim = c(0, 30), xlim = c(0, 50), xlab = "", ylab = "", cex = 1.5, pch = c(21, 22)[as.factor(roscomp[, 9])], cex.lab = 1.5, cex.axis = 1.5, col = "white", bg = "mediumpurple")
#text(.18, 0.95, labels = "B", cex = 1.5)
abline(lm(roscomp[, 5]~roscomp[, 8]), col = "mediumpurple", lwd = 2)
matlines(newx.corr, preds.ANDcorr[, 2:3], col = "mediumpurple", lty = 2, lwd = 2)
text(40, 2, labels = LM.R2.AnCorr, cex = 1.5)
abline(0, 1, lwd = 2)

par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0), mar = c(0, 0, 0, 0), new = TRUE)
plot(0, 0, type = "n", bty = "n", xaxt = "n", yaxt = "n")
text(-1.04, 0.075, labels = y, srt = 90, cex = 1.5)
text(-.45, -1.02, labels = x1, cex = 1.5)
text(.56, -1.02, labels = x2, cex = 1.5)
text(-0.85, 0.92, labels = "A", cex = 1.5)
text(.18, 0.92, labels = "B", cex = 1.5)

#RMSE evaluations for bewtween model comparisons of rates of spread
rmse.davies1 <- rmse(roscomp[, 1], roscomp[, 3])
rmse.davies2 <- rmse(roscomp[, 1], roscomp[, 4])
rmse.anderson <- rmse(roscomp[, 1], roscomp[, 5])
rmse.roth <- rmse(roscomp[, 1], roscomp[, 2])
rmse.behave <- rmse(roscomp[, 1], roscomp[, 6])
rmse.farsite <- rmse(roscomp[, 1], roscomp[, 7])
rmse.corr <- rmse(roscomp[, 8], roscomp[, 5])

rmse.davies1.h <- rmse(roscomp[1:9, 1], roscomp[1:9, 3])
rmse.davies2.h <- rmse(roscomp[1:9, 1], roscomp[1:9, 4])
rmse.anderson.h <- rmse(roscomp[1:9, 1], roscomp[1:9, 5])
rmse.roth.h <- rmse(roscomp[1:9, 1], roscomp[1:9, 2])
rmse.behave.h <- rmse(roscomp[1:9, 1], roscomp[1:9, 6])
rmse.farsite.h <- rmse(roscomp[1:9, 1], roscomp[1:9, 7])
rmse.corr.h <- rmse(roscomp[1:9, 8], roscomp[1:9, 5])

rmse.davies1.h
rmse.davies2.h 
rmse.anderson.h
rmse.roth.h 
rmse.behave.h 
rmse.farsite.h 
rmse.corr.h

rmse.davies1.m <- rmse(roscomp[10:18, 1], roscomp[10:18, 3])
rmse.davies2.m <- rmse(roscomp[10:18, 1], roscomp[10:18, 4])
rmse.anderson.m <- rmse(roscomp[10:18, 1], roscomp[10:18, 5])
rmse.roth.m <- rmse(roscomp[10:18, 1], roscomp[10:18, 2])
rmse.behave.m <- rmse(roscomp[10:18, 1], roscomp[10:18, 6])
rmse.farsite.m <- rmse(roscomp[10:18, 1], roscomp[10:18, 7])
rmse.corr.m <- rmse(roscomp[10:18, 8], roscomp[10:18, 5])

rmse.davies1.m
rmse.davies2.m 
rmse.anderson.m
rmse.roth.m
rmse.behave.m 
rmse.farsite.m 
rmse.corr.m

rmse.davies1.l <- rmse(roscomp[19:27, 1], roscomp[19:27, 3])
rmse.davies2.l <- rmse(roscomp[19:27, 1], roscomp[19:27, 4])
rmse.anderson.l <- rmse(roscomp[19:27, 1], roscomp[19:27, 5])
rmse.roth.l <- rmse(roscomp[19:27, 1], roscomp[19:27, 2])
rmse.behave.l <- rmse(roscomp[19:27, 1], roscomp[19:27, 6])
rmse.farsite.l <- rmse(roscomp[19:27, 1], roscomp[19:27, 7])
rmse.corr.l <- rmse(roscomp[19:27, 8], roscomp[19:27, 5])

rmse.davies1.l
rmse.davies2.l 
rmse.anderson.l
rmse.roth.l
rmse.behave.l 
rmse.farsite.l 
rmse.corr.l

#1:1 LPA evaulations to compare each prediction model with observations of fire behavior
rothpredobs.lm <- lm(roscomp[, 2]~roscomp[, 1])
crothpredobs.lm <- c(rothpredobs.lm$coefficients)
srothpredobs.lm <- summary(rothpredobs.lm)
trothpredobs.lm <- (1 - crothpredobs.lm[2])/srothpredobs.lm$sigma
trothpredobs.lm

pred1predobs.lm <- lm(roscomp[, 3]~roscomp[, 1])
cpred1predobs.lm <- c(pred1predobs.lm$coefficients)
spred1predobs.lm <- summary(pred1predobs.lm)
tpred1predobs.lm <- (1 - cpred1predobs.lm[2])/spred1predobs.lm$sigma
tpred1predobs.lm

pred2predobs.lm <- lm(roscomp[, 4]~roscomp[, 1])
cpred2predobs.lm <- c(pred2predobs.lm$coefficients)
spred2predobs.lm <- summary(pred2predobs.lm)
tpred2predobs.lm <- (1 - cpred2predobs.lm[2])/spred2predobs.lm$sigma
tpred2predobs.lm

pred3predobs.lm <- lm(roscomp[, 5]~roscomp[, 1])
cpred3predobs.lm <- c(pred3predobs.lm$coefficients)
spred3predobs.lm <- summary(pred3predobs.lm)
tpred3predobs.lm <- (1 - cpred3predobs.lm[2])/spred3predobs.lm$sigma
tpred3predobs.lm

BEHpredobs.lm <- lm(roscomp[, 6]~roscomp[, 1])
cBEHpredobs.lm <- c(BEHpredobs.lm$coefficients)
sBEHpredobs.lm <- summary(BEHpredobs.lm)
tBEHpredobs.lm <- (1 - cBEHpredobs.lm[2])/sBEHpredobs.lm$sigma
tBEHpredobs.lm

FARpredobs.lm <- lm(roscomp[, 7]~roscomp[, 1])
cFARpredobs.lm <- c(FARpredobs.lm$coefficients)
sFARpredobs.lm <- summary(FARpredobs.lm)
tFARpredobs.lm <- (1 - cFARpredobs.lm[2])/sFARpredobs.lm$sigma
tFARpredobs.lm

corrpredobs.lm <- lm(roscomp[, 5]~roscomp[, 8])
c.corrpredobs.lm <- c(corrpredobs.lm$coefficients)
s.corrpredobs.lm <- summary(corrpredobs.lm)
t.corrpredobs.lm <- (1 - c.corrpredobs.lm[2])/s.corrpredobs.lm$sigma
t.corrpredobs.lm

#Create stacked data frame from fire behaviour matrix that can be used for stats
ROSAOV <- data.frame()

ROSAOV[1:27, 1] <- roscomp[, 2]
ROSAOV[1:27, 2] <- "Roth"
ROSAOV[1:9, 3] <- "High"
ROSAOV[10:18, 3] <- "Mod"
ROSAOV[19:27, 3] <- "Low"

ROSAOV[28:54, 1] <- roscomp[, 3]
ROSAOV[28:54, 2] <- "Davies1"
ROSAOV[28:36, 3] <- "High"
ROSAOV[37:45, 3] <- "Mod"
ROSAOV[46:54, 3] <- "Low"

ROSAOV[55:81, 1] <- roscomp[, 4]
ROSAOV[55:81, 2] <- "Davies2"
ROSAOV[55:63, 3] <- "High"
ROSAOV[64:72, 3] <- "Mod"
ROSAOV[73:81, 3] <- "Low"

ROSAOV[82:108, 1] <- roscomp[, 5]
ROSAOV[82:108, 2] <- "Anderson"
ROSAOV[82:90, 3] <- "High"
ROSAOV[91:99, 3] <- "Mod"
ROSAOV[100:108, 3] <- "Low"

ROSAOV[109:135, 1] <- roscomp[, 6]
ROSAOV[109:135, 2] <- "BEH"
ROSAOV[109:117, 3] <- "High"
ROSAOV[118:126, 3] <- "Mod"
ROSAOV[127:135, 3] <- "Low"

ROSAOV[136:162, 1] <- roscomp[, 7]
ROSAOV[136:162, 2] <- "FAR"
ROSAOV[136:144, 3] <- "High"
ROSAOV[145:153, 3] <- "Mod"
ROSAOV[154:162, 3] <- "Low"

colnames(ROSAOV) <- c("ROS", "PRED", "MODEL")

#ANOVA for rates of spread versus the interaction of fire behavior prediction model and fire behavior class
predobs.aov <- aov(ROS~PRED*MODEL, data = ROSAOV)

qqnorm(residuals(predobs.aov))
qqline(residuals(predobs.aov))

summary(predobs.aov)

#post-hoc analysis for the ANOVA above
TukeyHSD(predobs.aov)

#ANOVA sample size
pwr.2way(a = 6, b = 3, alpha = 0.05, size.A = 27, size.B = 54, f.A = 28.608, f.B = 33.747, delta.A = 0.0116, delta.B = 0.525, sigma.A = NULL, sigma.B = NULL)

#References
#Anderson, W.R.; Cruz, M.G.; Fernandes, P.M.; McCaw, L.; Vega, J.A.; Bradstock, R.A.; Forgarty, L.; Gould, J.; McCarthy, G.; Marsden-Smedley, J.B.; Matthews, S.; Mattingley, G.; Pearce. H.G.; van Wilgen, B.W. A generic, empirical-based model for predicting rate of fire spread in shrublands. Int. J. Wildland Fire 2015, 24, 443-460. https://doi.org/10.1071/WF14130
#Andrews, P.L. Current status and future needs of the BehavePlus Fire Modeling System. Int. J. Wildland Fire 2013, 23, 21-33. https://doi.org/10.1071/WF12167
#Davies, G.M.; Legg, C.J.; Smith, A.A.; MacDonald, A.J. Rate of spread of fires in Calluna vulgaris-dominated moorlands. J. Appl. Ecol. 2009, 46, 1054-1063. https://doi.org/10.1111/j.1365-2664.2009.01681.x
#Finney, M.A. Farsite: Fire Area Simulator - Model Development and Evaluation; RMRS-RP-4; U.S. Department of Agriculture, Forest Service, Rocky Mountain Research Station: Fort Collins, CO, 2004. https://www.fs.usda.gov/treesearch/pubs/4617 (accessed 2019-10-2).
#Legg, C.J.; Davies, G.M.; Kitchen, K.; Marno, P. Developing a Fire Danger Rating System for Vegetation Fires in the UK: FireBeaters Phase I final report; Scottish Wildfire Forum, 2007. https://era.ed.ac.uk/handle/1842/3011 (accessed 2019-09-23).
#Vacchiano, G.; Ascoli, D. An Implementation of the Rothermel Fire Spread Model in the R Programming Language. Fire Technol. 2015a, 51, 523-535. https://doi.org/10.1007/s10694-014-0405-6



